import os

vi_chars = set(list(
    "àảãáạăằẳẵẴắẮặẶâÂầẦẩẨẫẪấẤậẬđĐèÈẻẺẽẼéÉẹẸêÊềỀểỂễỄếẾệỆìÌỉỈĩĨíÍịỊòÒỏỎõÕóÓôÔồỒổỔỗỖốỐộỘơƠờỜởỞỡỠớỚợỢùÙủỦũŨúÚụưƯừỪửỬữỮứỨựỰỳỲỷỶỹỸýÝ".lower()))

# non_oov_chars = set(list('/-'))

vi_dict = None


def format_word(text):
    text = text.lower()
    # text = text.replace('-', ' ')
    return text


def load_dictionary(file_path):
    with open(file_path, 'r', encoding='utf-8') as file:
        words = file.read().strip().split('\n')
    word_dict = []
    for word in words:
        word_formated = format_word(word)
        # word_dict.append(word_formated)
        word_dict.extend(word_formated.split())
    word_dict.extend(list('".,?!@#$%^&*()_-+=\';:<>/`'))
    return set(word_dict)


def check_oov_word(word):
    global vi_dict
    if vi_dict is None:
        vi_dict = load_dictionary(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'vidict.txt'))

    if format_word(word) in vi_dict:
        return False
    if len(set(list(word)).intersection(vi_chars)) > 0:
        return False

    return True



list_word_abb = {"gdđt", "pctpmt", "sđnđ", "cnht", "mttqvn", "đhclc", "ks", "ytế", "pcthtl", "kst", "nhnnvn", "hsgqt",
                 "ndtv", "dnnvv", "tn-mt", "gplx", "khcn", "tcmn", "tntt", "dvtt", "qcdccs", "pkl", "hvnclc", "csvn",
                 "qbv", "tttm", "pnvn", "hđtt", "pclbtư", "tnhh", "vhgdttnnđ", "ctn", "lct", "pccn", "qp", "dtnn",
                 "hvannd", "thvn", "hvnh", "shnn", "vnd", "gcnqsdđơ", "plvn", "vnn", "hqhp", "dnvn", "hkvn", "hđt",
                 "cntt", "gcmnd", "hvkhqs", "khktnnmn", "hdv", "dhs", "dhktcn", "nhnt", "qlhc", "gd", "hq", "bcđts",
                 "bhl", "hđnd", "kdcn", "nsx", "ktv", "đd", "cntn", "hmnđ", "đkđt", "csđn", "xs", "pcc", "btv", "ttvgt",
                 "hdnd", "bhnn", "ksnd", "lllđ", "ndcm", "qsmt", "qbv", "tbmmn", "tctt", "lntt", "bvmt", "tpdn",
                 "sgtvt", "uvbct", "pcmt", "pcgdbth", "tnxk", "xdntm", "gstskh", "hđcd", "plvn", "đkvn", "đhbkhcm",
                 "lđtbxh", "qcgnhh", "gdgt", "ttdh", "đkdt", "xklđ", "qckdtxd", "csnd", "pcgdthcs", "sx", "tnk", "ptt",
                 "nmld", "ttvn", "ccb", "chqs", "csdc", "xs", "ttytdp", "kt-xh", "hđcdgsnn", "tmdv", "tthtsv", "sdđnn",
                 "gt", "ub", "ngnd", "bđn", "nđ", "bxh", "ptnt", "cđsp", "tpcn", "hnv", "hngđ", "sgd", "đtv", "bchcd",
                 "thpt", "hđtđ", "pghh", "bhtn", "gplhđb", "cs", "lđbđvn", "tcttmsg", "hkvn", "đhbkhn", "nhtmcp",
                 "tbnn", "nst", "ttkttv", "qh-kt", "đtla", "tcvn", "tpcp", "khkd", "tddc", "tctn", "cshs", "tpo", "tdv",
                 "attt", "atvstp", "lntt", "csmt", "gt-vt", "đcs", "thgt", "tnxh", "bcđt", "bnhv", "bchtw", "nx",
                 "qcvn", "dnt", "hsgqg", "ktnt", "gdpt", "mttq", "bs", "vsattp", "tcbvntd", "ttxvn", "đt", "ktnt",
                 "ttbđs", "đhhvn", "thqg", "atnđ", "vksnd", "bgd", "nhtmnn", "hcvl", "pcccr", "phhs", "đbtsxb", "gcn",
                 "tckt", "tttv", "ttdvvl", "dvvl", "vpcc", "tpcp", "tb-xh", "gdcd", "qp", "blv", "hcv", "tth", "gcnkqt",
                 "tnmt", "nls", "bctn", "pctt", "ptth", "rlc", "pclbtw", "kcn", "bnhv", "dnbh", "ttnn", "kd", "vphc",
                 "cktg", "nxbgd", "sggpo", "bhnn", "csđttpmt", "bts", "ktx", "sbt", "bctc", "nn-ptnt", "lđbđ", "ss",
                 "ktqd", "sxkd", "nnvn", "gcnqshnơ", "đhktcn", "chxhcn", "qsdđ", "cnht", "vlxd", "kkt", "btbnn", "hl",
                 "bltths", "gptm", "hlqg", "hđcdgs", "hhhv", "pcccr", "kts", "syll", "đhđd", "ktxh", "mtv", "đbtn",
                 "đhgtvt", "tskh", "hđkt", "tchl", "dn", "pclb", "nqd", "ghz", "ptnn", "cccd", "bqt", "qltt", "nhđa",
                 "km/h", "gcnđkkd", "cnv", "tvv", "cbtt", "cnqsdđ", "đkxt", "cbpg", "tx", "hssv", "đkvđ", "gdpt",
                 "lltp", "nhnnptnt", "dl", "đhnt", "cbpg", "stt", "tchq", "tcs", "ttđm", "hn", "bvđk", "tt-tt", "pgs",
                 "bcc", "qt", "tno", "đhbc", "ndt", "km/h", "gđtla", "đkhk", "nnt", "qsd", "đhdl", "cqđt", "ktnn",
                 "csg", "tctd", "ubmttqvn", "vltk", "đcsvn", "shtd", "btvh", "ttkttv", "gdkhq", "lmlm", "hsmt", "cmcn",
                 "qk", "vtv", "qcvn", "đhbk", "nsnn", "hđts", "ptv", "ndvn", "tkcn", "gdnn", "bđs", "hvbcvt", "csmt",
                 "tvn", "gdđh", "ttgt", "xhtt", "pttm", "lhtnvn", "đhkh", "nvh", "gcq", "hvcnbcvt", "tnnt", "tbtt",
                 "pl", "atgt", "hnd", "nncnc", "tbnn", "kđcl", "ckqt", "hđlđ", "kk", "sbt", "đvttn", "đtnn", "đkkh",
                 "tg", "gtgd", "tbt", "đhqghn", "bk", "đhđcqt", "pctpcnc", "gdcd", "mxh", "ttatxh", "pgđ", "ctck",
                 "hsd", "bgdđt", "hđct", "csđt", "hs-sv", "ct", "ptcs", "pgs-ts", "gsts", "gs.ts", "bhtg", "ttbyt",
                 "đta", "tnđt", "tctn", "gcnsk", "kqkd", "t.ư", "gđtt", "ctrl", "gv", "ntbd", "nvhtn", "kcn-kcx",
                 "pccc", "gpnk", "hqđt", "gs-ts", "xdcb", "cstt", "vhtt", "tđbkvn", "vh-tt-dl", "ttks", "cskv", "kdc",
                 "tcn", "bhtn", "vbqppl", "ktstq", "tsn", "svđ", "ltqđtd", "tcvsg", "cspctpmt", "vpcp", "gdkhq", "mbh",
                 "bchqs", "csvc", "ttck", "tpdn", "nhm", "blhs", "ghpgvn", "gsht", "lltp", "đhqg", "cmt", "xskt", "nx",
                 "pctn", "lhpnvn", "nhcthp", "cv", "vthkcc", "hsđkdt", "lđ", "nlđ", "dtts", "đvưt", "vpqh", "ts-bs",
                 "gcnqsh", "vhttdl", "pbgdpl", "vqg", "llvtnd", "ptn", "đhcđ", "nsưt", "qncn", "hđba", "vh-tt", "sv–hs",
                 "ttcn", "bvtv", "thads", "tntp", "kdhđc", "cscđ", "ttct", "đhktqd", "cnvc", "xdhk", "bltths", "pmh",
                 "csb", "bpck", "qbltd", "gcnqsdđ", "qhtd", "kt-xh", "mtqg", "bqt", "p/v", "qckt", "ntnn", "bctn", "qg",
                 "bcs", "đttx", "klđt", "đtqg", "mg/kg", "nxbvhtt", "cđ", "bn", "vpcc", "kcnc", "gdvn", "tphcm",
                 "tp.hcm", "hđndtp", "xh", "nckh", "bst", "pcthcs", "ktcn", "vsattp", "ykvn", "ctclqg", "hlttqg",
                 "lđlđ", "nhctcn", "cp", "cahn", "gdtx", "ttgdck", "cssx", "cvpm", "hhhv", "vnch", "anđt", "dtht",
                 "dntn", "khđt", "mxh", "ttdh", "nvqs", "đhcn", "đbp", "qs", "antg", "tmcp", "ctch", "tgpl", "cchc",
                 "ubmttq", "tnv", "svvn", "chdc", "hsdt", "đhkt", "bcvt", "gđđh", "bhtg", "ptdtnt", "ttth", "đthvn",
                 "cnkt", "đmn", "xnc", "pclb", "kh-cn", "csqlhc", "tt", "cbccvc", "tacn", "annd", "bhxh", "kcx", "hv",
                 "pk-kq", "hkddvn", "ttxh", "vh-tt-dl", "cpttt", "khlcnt", "pk-kq", "csdl", "qchq", "vksndtc", "lb",
                 "nn", "cpsxtm", "tmdv", "sv", "xđgn", "bcđđmđh", "pnvn", "qld", "thcb", "ttdv", "thdl", "cđv",
                 "nhđtpt", "nhtmqd", "qsmt", "qt", "ttbdvh", "lnst", "mtth", "ubnd", "nkt", "gt-vt", "gs", "tbktsg",
                 "ncc", "gp", "đvtn", "đtlt", "rlcd", "tthc", "kcn-kcx", "stk", "thktsmđ", "mtqg", "mtth", "pct",
                 "csxh", "tand", "tthc", "ctcc", "kđtntl", "nsut", "nmđ", "pcth", "ttks", "nknv", "sg", "gmd", "svhs",
                 "kv3", "tcmr", "vnm", "dnvvn", "vđ", "qpan", "cntt-tt", "dvmtr", "stk", "nlmt", "tncs", "vpqh", "cmcn",
                 "nkkn", "ts", "đhkhtn", "catw", "sđh", "tdtt", "spkt", "kttt", "pctpmt", "kv1", "svđv", "vnđ", "pcgd",
                 "đhđn", "nđt", "hcm", "hđcdgscs", "vbqppl", "bp", "ctcn", "ndtv", "nkbv", "gcnqsd", "sxh", "mg/kg",
                 "vđqg", "dvtmcm", "pgd", "hd", "hctc", "hs", "sđtla", "ctđl", "hkhktvn", "đtqg", "vsmt", "ktstq",
                 "dvmtr", "khktnn", "nv", "atttgt", "qtdnd", "hkqt", "tnsvvn", "vh-tt", "tnvn", "bcđpctntư", "nsx",
                 "tct", "hđnd", "hkqt", "ttqlkt", "đkkd", "htxnn", "ttgdtx", "chqs", "thkts", "nmld", "ttxd", "pgs-ts",
                 "nxbkhxh", "nsut", "hnht", "kntc", "nhtw", "qđ", "tddc", "gvcn", "kđt", "ubtvqh", "hđnt", "gs-ts",
                 "ubtdtt", "htxdvnn", "qh", "ndcm", "uvbch", "gstt", "sbd", "bhyt", "tttv", "hsd", "đtvhd", "pttt",
                 "vphc", "tmn", "pctp", "tnđh", "kdnpn", "đhsp", "vac", "kddv", "qh-kt", "tcdl", "khkths", "kđtm",
                 "hđqt", "attp", "tntn", "xttm", "hđ", "klqg", "dqtv", "tncn", "cncn", "tngt", "đhkhtnhn", "ctđ",
                 "chdcnd", "htx", "xdntm", "chkqt", "nđvn", "đna", "dd", "hđcdgsn", "gdvn", "lđtb", "tndn", "bcs",
                 "catp", "đhct", "qppl", "hmtn", "bpck", "tns", "khtn", "lhpnvn", "nncđdc", "smđh", "kđs", "bqp", "bs",
                 "ubndtp", "khxh", "cnch", "cskh", "vhnt", "dtqg", "pmh", "nxbtn", "kđclgd", "tgđ", "cbtt", "hktt",
                 "lnst", "bchtư", "tvqh", "bbt", "bhnt", "tnsv", "hsmt", "br-vt", "nvqs", "ctth", "nhtư", "thx", "đvht",
                 "cnxh", "gb", "lhtn", "ths", "bct", "cbcnv", "gdck", "tnnd", "đhhb", "nltt", "ghz", "hlv", "pcgdth",
                 "ttyt", "ttđb", "nsnd", "dtts", "hmtn", "ttatgt", "pctnxh", "nnptnt", "kcx-kcn", "tbn", "tw", "bcđ",
                 "vnch", "xhcn", "ksndtc", "vks", "dagtđt", "khls", "ttvh", "bot", "blttds", "qncn", "pv", "tbxh",
                 "kv2", "dcch", "xdll", "pgs.ts", "tnt", "nctt", "blv", "annd", "hhvn", "tbn", "npp", "ktxh", "cskt",
                 "đk", "hsbc", "qđnd", "cpxd", "utgt", "clb", "pt-th", "pcbltkcn", "xnk", "mtđt", "pbgdpl", "tbktvn",
                 "vđvqg", "lhq", "xdll", "chxhcn", "hcđ", "vhttdl", "nn-ptnt", "đhbktphcm", "ll", "tpct", "vsmt",
                 "hhtg", "lts", "thcs", "kcb", "nhtm", "htcđ", "gvtn", "shtt", "m/s", "ck", "cand", "stt", "csb",
                 "th.s", "lsq", "tsdđ", "blds", "ubdt", "bxl", "nxbqđnd", "ttbvqtg", "ncl", "tp", "lhp", "nhctvn",
                 "nv2", "đtđ", "gđt", "gtvt", "lhs", "cbnv", "blttds", "llvtnd", "cnch", "csgt", "ndvn", "gvth", "ttn",
                 "gtcc", "m/s", "tnkq", "hđh", "sđt", "gpmb", "blds", "vpđd", "ttk", "đbscl", "nv3", "đtb", "tckh",
                 "tcct", "hspt", "nhm", "chkqt", "cbnv", "sđk", "tvhk", "tnxp", "hkdd", "ttttn", "bđvn", "ktm", "tđc",
                 "bl", "qlhc", "ntk", "tandtc", "bhnt", "slna", "cbqlgd", "pclbmn", "hb", "sxkd", "tmđt", "nhcsxh",
                 "lhpn", "bl", "thcsnđ", "ms", "pcbth", "vck", "tnhc", "htxnn", "chlb", "anqg", "đtvn", "hvch", "pccn",
                 "đcstq", "cptd", "gs-tskh", "qtdnd", "xnc", "llvt", "pcmt", "ubkt", "ntts", "cn", "cstt", "bqp",
                 "nn & ptnt", "nn&ptnt", "antq", "thcn", "đná", "tnln", "cttc", "chnd", "kh-đt", "anct", "bgk", "mtxt",
                 "ntnn", "tcnn", "bks", "thtt", "qppl", "kqkd", "antv", "tdttqg", "qlđt", "mhz", "bql", "gtgt", "dtnn",
                 "qs", "tn-mt", "qcdc", "tto", "ptnn", "tccn", "tcct", "csđttp", "ntts", "cnxh", "nn&ptnt", "ptdtnt",
                 "ksv", "đbdt", "bqlda", "hagl", "dnnn", "snn", "hctl", "btc", "tpcđ", "kttt", "vđv", "đb", "ktqdhn",
                 "skhcn", "bhđc", "đh", "khlcnt", "thads", "hđđg", "gdck", "svtn", "ncs", "cph", "đsq", "kcx-kcn",
                 "ngnd", "cttt", "bx", "sgk", "cspk", "nhđt", "dqtv", "cbcs", "gsht", "bvmt", "tbd", "tccs", "tthtcđ",
                 "ttdd", "ntd", "xhh", "ddvn", "ttxd", "skss", "gtnt", "hlbđ", "gtmt", "vthkcc", "nv1", "dv", "pcthtl",
                 "nncnc", "kdn", "ttton", "hsdt", "gdmn", "đttxqm", "tttt", "lts", "tt-tt", "bgh", "hđđb", "skhcnmt",
                 "vp", "bch", "kttv", "nnt", "ytdp", "bbcvt", "antv", "pctp", "kbnn", "htx", "khkt", "ls", "ctsn", "bv",
                 "cbcc", "ttbdvhng", "gtgd", "đtxdcb", "hvn", "ttlt", "cđdc", "cmnd", "cmt", "bctc", "vhgdtntn", "nhđá",
                 "đhktcn", "mhx", "gpxd", "ckqt", "pkl", "tq", "đhkhxh", "kwh", "dnnvv", "bxh", "hvncl", "ttcp", "csnd",
                 "gdmn", "ts-bs", "đhn", "skhđt", "lmlm", "sggp", "cbccvc", "hcb", "hphn", "cccd", "tntt", "bh", "đc",
                 "hđxx", "đtdđ", "dnbh", "cnh", "ctcp", "nhnn", "cttnhh", "nxb", "gđ", "kcnc", "đbqh", "khkthn", "tsvm",
                 "ctv", "gvg", "csđtlx", "cnsh", "pcbl", "ctrl", "sgtt", "cntt-tt", "kh-cn", "sdđ", "tttt", "svnckh",
                 "gs-tskh", "ưcv", "hsv", "xhtt", "qtkd", "bcđqg", "hsg", "hkhkt", "ubcknn", "kdl", "pgd", "đrl",
                 "gvmn", "htnd", "gcnqshn", "kdđv", "cq", "ctxh", "qlda", "bđ", "antq", "atgt", "atkt", "bbcvt", "bbn",
                 "bbn", "bchbp", "bchcđcs", "bchqs", "bcsđ", "bcvn", "bcvt", "bcđ", "bcđqg", "bcđt", "bcđđmđh", "bđm",
                 "bđvh", "bdvhx", "bgk", "bgtvt", "bhhs", "bhvn", "bhx", "bhxh", "bhyt", "bkh", "bkhcn", "bkhđt", "bkt",
                 "blds", "bll", "blv", "blx", "bmte", "bng", "bnn", "bpck", "bql", "br-vt", "bqlda", "bqlr", "bqp",
                 "bqtg", "brvn", "btc", "btccbcp", "btđ", "btdt", "btdtcđ", "btgđ", "btlstn", "btm", "btnmt", "btp",
                 "btvh", "btđuk", "bvbmte", "bvbđ", "bvhtt", "bvm", "bvmt", "bvnđ", "bvpl", "bvđk", "bvđkt", "bxd",
                 "bxl", "bđbb", "bđhn", "bđvhx", "cahn", "cahp", "catp", "catx", "cbcnv", "cbtc", "cbtp", "cbts",
                 "cbtsxk", "cbđ", "cbđv", "ccbvnlts", "cchkmt", "ccq", "ccrđ", "cdat", "cddl", "cđv", "cđvn", "chbp",
                 "chdc", "chlb", "chlbđ", "chnd", "chrm", "chxh", "chxhcnvn", "cknn", "ckvn", "clb", "clbhk", "clqg",
                 "cmnd", "cmvh", "cnbcvt", "cncl", "cncđ", "cnh", "cnkt", "cnlđ", "cnnt", "cnpm", "cnqsd", "cnqsdđ",
                 "cnv", "cnvclđ", "cnvl", "cnvqp", "cnxh", "cpbđ", "cpdvdl", "cphh", "cptb", "cptm", "cptđ", "cpxdct",
                 "cpxdls", "cpđtpt", "cpđtxd", "cqca", "cqcsđt", "cqlg", "cqđd", "cqđv", "cscn", "csgt", "csgtđt",
                 "cshs", "cskh", "cskt", "cskv", "csmt", "csnd", "cspccc", "cspcmt", "csqlhc", "cssk", "cstq", "cstt",
                 "csxk", "csđttpmt", "ctcs", "ctđ", "ctgt", "ctkt", "ctlt", "ctph", "ctqg", "ctub", "ctđt", "cvh",
                 "cvnt", "cvpm", "cvđ", "cxt", "cđan", "cđbc", "cđbđ", "cđcn", "cđcs", "cđcđ", "cđdc", "cđkt", "cđnh",
                 "cđnhvn", "cđnn", "cđqp", "cđskđa", "cđsl", "cđsp", "cđspmg", "cđv", "cđvc", "cđvcvn", "cđvn", "cđxd",
                 "cđxdvn", "cđđh", "dcnd", "đcq", "đctc", "đđk", "đhkh", "đhkt", "đhqghn", "đhsp", "dkđ", "đlđ",
                 "dlktcn", "dlnn", "dltm", "đltn", "dmct", "đmp", "dncm", "dnnn", "dnqđ", "dntnmt", "dnxk", "đpt",
                 "dsst", "dstg", "dsvh", "dsx", "dtlsvh", "dtnt", "dtnđ", "đtqg", "dttn", "dtts", "dvđa", "đvđd",
                 "dvktc", "đvtn", "dvvh", "dvvl", "gbb", "gcnqsd", "gcnqsh", "gdbđs", "gdcd", "gdck", "gdcktphcm",
                 "gdln", "gdlđxh", "gdtc", "gdth", "gd&đt", "gdtx", "gdđb", "gghb", "ghvn", "gpkd", "gplx", "gpđc",
                 "grtn", "gtcc", "gtct", "gtdt", "gtvl", "gtvt", "gvcn", "gx", "gđkt", "gđnn", "gđpy", "gđv", "gđvh",
                 "gđyk", "gđyp", "hcđv", "hclđ", "hcpt", "hcth", "hcvl", "hđdt", "hđnd", "hds", "hđtp", "hđtv", "hdv",
                 "hdxx", "hhhv", "hht", "hhtgnv", "hkcc", "hkddvn", "hkhkt", "hkmt", "hkpđ", "hkqt", "hkvn", "hlkh",
                 "hlqg", "hltl", "hlttqg", "hmtd", "hnb", "hncc", "hngđ", "hnlqt", "hnv", "hnvvn", "hqck", "hqtp",
                 "hsb", "hscb", "hsg", "hspt", "hsst", "hsv", "htchđpc", "htck", "htcs", "htđ", "htkt", "htlđ", "htms",
                 "htt", "httđ", "htx", "hvb", "hvch", "hvt", "hđa", "hđba", "hđbalhq", "hđbt", "hđcdgsnn", "hđck",
                 "hđcn", "hđct", "hđdt", "hđgpmb", "hđgtgt", "hđh", "hđhc", "hđhn", "hđkl", "hđlđ", "hđnd", "hđnt",
                 "hđqg", "hđqt", "hđtc", "hđtd", "hđtm", "hđtr", "hđts", "hđut", "hđvc", "kcb", "kcn", "kcnđn", "kcs",
                 "kcx", "kdc", "kdc", "kdl", "kdtv", "khcn", "khcnmt", "khdt", "khhgđvn", "khkt", "khktnn", "khls",
                 "khqs", "khtn", "khxb", "khxh", "khđ", "kkt", "klgđ", "klqg", "kltg", "kltt", "klđt", "ksbpck", "kslh",
                 "ksnd", "kstb", "ksđn", "ksđt", "ktck", "kths", "ktkl", "ktkt", "ktlt", "ktns", "ktpt", "ktqd", "ktqg",
                 "ktqt", "ktt", "ktth", "ktth", "kttt", "kttv", "kttvqg", "ktva", "ktvh", "ktx", "ktxh", "ktđt", "kvc",
                 "kvi", "kđs", "kđt", "lbq", "lcdb", "lcta", "lđbđvn", "lgs", "lgt", "lhchvhnt", "lhp", "lhpn", "lhpqt",
                 "lhpvn", "lhtt", "lhtt", "lhttqg", "llpb", "llvt", "llvtnd", "lnt", "lpn", "lqđ", "lqtt", "lqđ",
                 "lstn", "lsđ", "ltmn", "ltnln", "lttc", "lttt", "lvn", "lđbb", "lđbc", "lđbr", "lđbđvn", "lđc", "lđcl",
                 "lđcs", "lđcđ", "lđhn", "lđld", "lđlđ", "lđlđtp", "lđlđvn", "lđm", "lđnc", "lđqv", "lđqvvn", "lđsx",
                 "lđt", "lđtb", "lđttđna", "lđvl", "lđx", "lđxs", "lđxđ", "lđđc", "lđđk", "mdc", "mdp", "mdv", "mhv",
                 "mhx", "mqs", "mtgp", "mtkc", "mtlđ", "mtn", "mtqt", "mttg", "mttn", "mttqvn", "mvt", "navn", "nbx",
                 "nccdv", "ncq", "ncqlkt", "nctt", "ncxh", "ndcm", "ndnb", "ndnd", "ndtp", "ndvn", "nhcp", "nhkvn",
                 "nhl", "nhld", "nhm", "nhnn", "nhnnptnt", "nhnnvn", "nhqd", "nhtm", "nhtmnn", "nhtmqd", "nkts", "nkxd",
                 "nlgmn", "nlmt", "nln", "nlntvn", "nlđvn", "nmxlnt", "nmđ", "nmđt", "nncđmdc", "nndc", "nnđc", "nqa",
                 "nqlt", "nqđh", "nsdlđ", "nsnavn", "nssk", "nsskvn", "nsvn", "nsđp", "ntdm", "ntgt", "nthh", "nthm",
                 "ntkn", "ntls", "ntqđ", "ntv", "ntđ", "ntđđ", "nvhlđ", "nvhn", "nvhtn", "nvn", "nvnonn", "nvql",
                 "nvscc", "nvvn", "nvx", "nxbgd", "nxdkp", "nxk", "nxn", "nđnb", "nđtp", "nđttn", "pabt", "pcbl",
                 "pccc", "pccr", "pcdc", "pcgd", "pcgdth", "pclb", "pcp", "pcsr", "pct", "pcth", "pctpmt", "phbc",
                 "phg", "phhs", "phkq", "phpt", "phqc", "plhđ", "pmk", "pnct", "pnte", "ppda", "ppdh", "pq", "ptcs",
                 "ptct", "ptdl", "ptds", "ptdt", "ptgd", "ptgvth", "ptgđ", "ptnk", "pttm", "pvv", "qcph", "qctt", "qđd",
                 "qhcđ", "qhqt", "qhsdđ", "qhtd", "qhtdld", "qktd", "qlbtdt", "qlbv", "qlclhh", "qlctđt", "qlctđtđl",
                 "qld", "qlda", "qldatđ", "qldađt", "qldb", "qlgtdt", "qlhc", "qlhcvttxh", "qlht", "qlkd", "qlkt",
                 "qlktx", "qllđ", "qllđnn", "qln", "qlnh", "qlnt", "qlnđ", "qlpt", "qlptn", "qlr", "qlsv", "qltn",
                 "qltsnn", "qltt", "qlttxd", "qlttđt", "qlxd", "qlxnk", "qlđb", "qlđs", "qlđs", "qlđt", "qs", "qsh",
                 "qshn", "qsqk", "qsđ", "qth", "qtlv", "qtns", "qx", "qyv", "qđcc", "qđkl", "qđndvn", "qđst", "qđtt",
                 "qđđc", "rphđn", "rtyt", "rđtg", "sbc", "sbt", "sđg", "sdq", "sdđ", "sgdck", "sgtvt", "sgv", "skct",
                 "skđa", "skhđt", "skmt", "skv", "skđa", "sll", "snn", "snv", "spcn", "sphh", "spkt", "sqlq", "sths",
                 "stt", "sttc", "sttt", "svh", "svh", "svđ", "svđqg", "svđv", "sxcn", "sxd", "sxnn", "sxtđ", "sxvlxd",
                 "sxxk", "taqs", "tbbp", "tbdđ", "tbgd", "tbls", "tblđ", "tbtt", "tbyt", "tcbc", "tcbđ", "tccb", "tccl",
                 "tcd", "tchq", "tcns", "tcpk", "tcspmn", "tct", "tctl", "tcv", "tcvn", "tcyttg", "tcđn", "tcđs", "tdg",
                 "tdk", "tdlđ", "tdnd", "tdte", "tđth", "tdtm", "tdts", "tgcc", "tgd", "tgdt", "tggd", "tgnv", "tgvl",
                 "tgđ", "thbc", "thbt", "thbtvh", "thca", "thhn", "thpt", "thsct", "thtk", "thtm", "tkk", "tkm", "tkt",
                 "tktk", "tkxd", "tlkh", "tlsq", "tltt", "tlvcđ", "tlđlđ", "tmcn", "tmcnvn", "tmcp", "tmlb", "tmls",
                 "tmmn", "tmmp", "tmnn", "tmqd", "tmth", "tmđb", "tnca", "tncq", "tncshcm", "tndc", "tnđh", "tndn",
                 "tndt", "tndtts", "tnhc", "tnhhnn", "tnhn", "tnk", "tnkt", "tnlđ", "tnmt", "tnn", "tnndcm", "tnnt",
                 "tns", "tntn", "tnvn", "tnxk", "tnxn", "tnxpgpmn", "tpbh", "tpdt", "tphn", "tphp", "tpn", "tpns",
                 "tpv", "tqgc", "tqvn", "trph", "tsgtks", "tskv", "tsnn", "tsqs", "ttatxh", "ttbh", "ttbtdt", "ttbvqtg",
                 "ttcd", "ttckvn", "ttcn", "ttctxh", "ttd", "ttgdlđ", "ttgdsk", "ttgtvl", "tthltt", "ttk", "ttks",
                 "ttlb", "ttlt", "ttmt", "ttnc", "ttnkt", "ttpc", "ttqg", "ttql", "ttqt", "ttsv", "tttm", "ttvhtt",
                 "ttvl", "ttvtđl", "ttxklđ", "tvcn", "tvdh", "tvhnbvn", "tvpl", "tvtk", "tvtu", "tvxdtl", "tyhg",
                 "tđbkvn", "tđtc", "ubatgt", "ubbcqh", "ubdn", "ubds", "ubdsgd", "ubdskhh", "ubdskhhgđ", "ubhc", "ubkh",
                 "ubkt", "ubktcđ", "ubktns", "ubnd", "ubqg", "ubtdtt", "ubtt", "ubtv", "ubtvqh", "ubvh", "ubxd", "ucv",
                 "utnk", "uvtv", "vbqppl", "vck", "vcqt", "vcvn", "vhdg", "vhdn", "vhdt", "vhgd", "vhhn", "vhhq",
                 "vhlđ", "vhlđhn", "vhnn", "vhnt", "vhntcdttsvn", "vhntvn", "vhqc", "vhsg", "vhtdtt", "vhtg", "vhth",
                 "vhtt", "vhttcs", "vhtttn", "vhvn", "vhđt", "vkhhs", "vks", "vksnd", "vksndtc", "vktbkt", "vlcn",
                 "vmx", "vnch", "vncn", "vndcch", "vndg", "vnh", "vnđ", "vpbcđ", "vpcp", "vpctn", "vpdd", "vphc",
                 "vpkv", "vpls", "vpp", "vpđd", "vqvn", "vrt", "vsatlđ", "vsdt", "vtdl", "vthh", "vthkcc", "vthkđs",
                 "vtnn", "vtt", "vttb", "vttl", "vttt", "vtvn", "vtyt", "vđc", "vđtg", "vđvqg", "xcg", "xdctgt", "xdhk",
                 "xdth", "xdtl", "xdtmsg", "xdvn", "xdđt", "xhnv", "xhtd", "xhtt", "xhvn", "xkld", "xkts", "xlnttt",
                 "xlth", "xlđ", "xmhm", "xmtn", "xmvn", "xnk", "xnkcn", "xnklt", "xnkth", "xnlt", "xntd", "xphc",
                 "xskt", "xtdl", "xtvl", "xtxnk", "xđgn", "xđttvn", "ykvn", "ytbd", "đatq", "đbqh", "đbsh", "đbth",
                 "đbtn", "đbvn", "đbxb", "đbđ", "đcnn", "đcnđ", "đcqt", "đcs", "đcslx", "đcstq", "đcđc", "đhdl", "đhh",
                 "đhht", "đhkh", "đhkhtn", "đhlđ", "đhmtcn", "đhnl", "đhnđ", "đhsp", "đhspbk", "đhtdtt", "đhtv", "đhvh",
                 "đhxd", "đhđl", "đkdn", "đkhk", "đkhđ", "đkkd", "đkqg", "đkst", "đktqt", "đkv", "đkvn", "đkvđqg",
                 "đkxt", "đlbtkl", "đldk", "đltphcm", "đlvn", "đmhn", "đna", "đnb", "đnnd", "đnntc", "đnt", "đpt",
                 "đptth", "đqg", "đrl", "đsvn", "đtb", "đtbc", "đtbđ", "đtbđqg", "đtcđ", "đtdd", "đth", "đtm", "đtnckh",
                 "đtncs", "đtnn", "đtnđ", "đtpt", "đtqg", "đttn", "đttp", "đtvt", "đtvtqg", "đtđ", "đtđh", "đvcđ",
                 "đvtn", "đvtv", "đđk", "đđv", "tmcp", "nxb", "pts", "đhkhxhnv", "bchtư", "qg", "lđbđ", "cnvc", "đb",
                 "nđ", "vđ", "hltt", "tnnd", "tmn", "smđh", "đtvn", "cbcnvc", "atgtqg", "atvslđ", "unbd", "atlđ",
                 "cbcn", "gvth", "hđ", "đhth", "cbgv", "đhbc", "ctcp", "bđh", "tmdl", "dnvn", "blđtbxh", "uvtư", "qsdđ",
                 "lsqs", "gđđh", "cđtư", "gtgd", "gddt", "csđttp", "atvstp", "ahlđ", "gccn", "đsq", "bgđ", "ubmttq",
                 "bvtư", "kttm", "gtđt", "nqtư", "lđtb&xh", "chtw", "anđt", "ctck", "csktxh", "atvs", "dnvt", "hphn",
                 "gtvtvn", "btxh", "đhcđvn", "pcn", "xnc", "đhktqd", "tbxh", "uvbch", "svhs", "tmdv", "cqtt", "vsat",
                 "catphcm", "ubmt", "hvl", "dvtm", "dnđ", "gstskh", "thph", "pgvn", "hđndtp", "lđbđtphcm", "lsqsvn",
                 "vhttdl", "tgpl", "cshcm", "cpxd", "tmt", "tthlqg", "csbv", "tn", "ck", "nv", "th", "tv", "vt", "ct",
                 "cb", "tlv", "vp", "xk", "nk", "ks", "dl", "cph", "gl", "cand", "mbh", "xd", "tm", "bd", "nm", "sx",
                 "qd", "gt", "ntd", "kn", "ns", "xm", "nb", "hv", "sk", "đs", "tưlđtt", "uv", "ubtư", "bk", "đk", "qc",
                 "bhtg", "cpptcn", "lhtnvn", "kk", "hbt", "đná", "ctmp", "cq", "antt", "nct", "đtmtt", "tccp",
                 "ubtưmttqvn", "xmhp", "pvđt", "nhtư", "tacn", "ưtxt", "bl", "bst", "hpnn", "vpqh", "bđg", "cnc", "ptn",
                 "ccgd", "qv", "cxh", "nsna", "mntt", "cpưđ", "tdv", "cmtnd", "hnd", "anqp", "chqs", "tcts", "tưmttqvn",
                 "tthnqg", "gdvn", "dtht", "đvkt", "ttb", "ctvn", "xdkt", "dkvn", "cqnn", "kktck", "hsvvn", "cndvđt",
                 "đtt", "bchtw", "tcyd", "gdtt", "qht", "lttp", "thth", "yt", "qtv", "đđcc", "bvyhcthn", "tnthpt",
                 "kdck", "ubndtphcm", "asxh", "ubtưmttq", "tsn", "vqgbe", "bltl", "tctcsvn", "cpptnn", "cmtm", "gh",
                 "dvgt", "hhtmtư", "khlm", "ubtw", "cvtdb", "bqlsc", "vptư", "đvttn", "kdtsq", "đlđđ", "ctpb", "lđdtts",
                 "kktm", "đctcp", "ctnhn", "ptpt", "nmdmk", "ttvhtw", "cbpg", "ghpgvn", "bacn", "dncph", "klhcndvđt",
                 "ktgs", "tưlđ", "ctdcvl", "bvqlntd", "hsd", "chcn", "pađm", "pmst", "udkh", "knkl", "dcgc", "cbtbs",
                 "ccqlts", "ctglvh", "tccvtqt", "ubkhcnmt", "pbt", "ttkttv", "vvntn", "thdlkt", "ttgdnpl", "khgd",
                 "kcndv", "vbhs", "htbs", "ubtwmttqvn", "qbqt", "gdgt", "ktts", "gdvđđ", "cbql", "lktđ", "khhkkg", "kg",
                 "ccbđ", "dhtc", "csgmgc", "bvđkbđ", "dsvhpvt", "stđt", "htxlnt", "mtcn", "ahllvtnd", "dvvtci",
                 "xnnttskt", "ksln", "gcntp", "kkl", "dnđtnn", "ntktt", "ccqltthp", "btđkcp", "cđđsvn", "dccs", "clbqđ",
                 "tlkhtư", "bhnn", "đhsk", "bchqstp", "htxnn", "lpcb", "vsdttw", "vhhtmtư", "nhtt", "cpbxktn", "ttgc",
                 "anvh", "gđtt", "qlcs", "bhmmtt", "btl", "kktns", "ctcpnb", "nhtw", "bqlkcnc", "thsp", "ttbctyt",
                 "tnptth", "ktcttl", "klhcndvđtbd", "tctcn", "gqvl", "dnpm", "hsgqg", "đxmt", "cpsh", "dnlh", "hhltvn",
                 "bvđktư", "hđndtphcm", "csdn", "tđcs", "ubtwmttq", "lptb", "kdlbcr", "cgđqlcl", "lsvn", "cđtt",
                 "ubdsgđte", "bdct", "bvpsqtsg", "bcvtvn", "bttevn", "cpxdctgt", "hhnh", "csđtbt", "btlsqg", "bctt",
                 "gtclvn", "gcpm", "yhlsbnđ", "tmncsg", "gdkhq", "cctg", "hcdhtt", "clsphh", "vsdttư", "đpctpmt",
                 "csht", "gvgđ", "tcbvntd", "ctcpxnklt", "cnttvn", "csgd", "lhhtxtm", "nmxxtb", "pvlđ", "pvxh", "đhyd",
                 "khkttv", "vpđdnn", "cmtt", "cncksg", "qlgt", "ktkltư", "atbxhn", "kgvhcctn", "gccnvn", "ahls",
                 "đcnđđt", "ccqlcl", "ttktptqđ", "csbvn", "đnhc", "cpbđpnrđ", "hkkg", "phcn", "bqlkcx", "ttlđtn",
                 "tbbttn", "htxvttl", "bcnckt", "ttdbkttvtw", "cthcqg", "hptvn", "tvskcđ", "bvtnmt", "gcxkpm", "dđtm",
                 "cđlđxh", "cpdnt", "bqlrđd", "dnvk", "qlnbt", "đhhh", "ldxd", "hđgđyk", "vntcncr", "tandtp", "hltdtt",
                 "anqg", "ntđygt", "lđxhtp", "tđtvn", "qlbvrph", "tctxdctgt", "dntư", "nđcbvts", "ckxd", "ttbđs",
                 "tktn", "lgqt", "lđbđla", "pvbc", "tmtw", "nlnt", "twmttqvn", "qstw", "ttkđxd", "ctxkts", "lpccbtn",
                 "tctdtt", "lđbđth", "ghpgtnvn", "bhxhvn", "qgtphcm", "kcntl", "tmsx", "cđnqd", "hlbv", "vđgq",
                 "ctytnhh", "lhtnsv", "cpts", "anttvh", "gttpm", "hhchctn", "hhhvtg", "adcnsxsh", "ttncktkh", "đtgq",
                 "pvbctt", "cttettvn", "kdxd", "htqlcl", "gđcatp", "xhcnvn", "cbvc", "cđspnh", "ubkc", "lpcbltgđ",
                 "bttt", "cthcqghcm", "tandtphcm", "lhctchn", "vudncnc", "qctm", "tctnn", "tlssg", "ccbvn", "bchtlđ",
                 "ubmttqtp", "cskdcd", "atđb", "ktsvn", "skctkt", "ttkstskv", "qlccttđ", "ttqlktvcv", "cchk", "hcgltm",
                 "gcntntt", "tsxhcn", "csđtpn", "vhttdt", "thptdl", "khpl", "antg", "antđ", "bcht", "bdcbyt", "bdvn",
                 "bgd", "bhty", "bhxhtn", "bks", "blhs", "bllđ", "bltths", "bmvnah", "bnv", "bqldactcc", "brvt", "btct",
                 "btthpt", "bttu", "bvbm", "bvcste", "bvtv", "bx", "bđcn", "bđi", "bđla", "bđvn", "bđđ", "cbcc", "cbcđ",
                 "cbnđ", "cbyt", "ccdv", "ccmn", "ccs", "cđcp", "cddc", "cgđ", "chkt", "chpclb", "clbtp", "cmn", "cng",
                 "cnvt", "cpbv", "cpck", "cptccg", "cpđosg", "cscđ", "csgttt", "cstn", "cstđ", "csvn", "csđttpvmt",
                 "ctqs", "cttđ", "ctxh", "ctyt", "ctđvn", "cvpmqt", "cvt", "cđbđvn", "cđcd", "cđcnvn", "cđcs", "cđcsvm",
                 "cđhn", "cđvh", "dcqhbn", "dctd", "dcxh", "dddn", "dhbk", "dhn", "dhtv", "dlhv", "dsgd", "dsgđ",
                 "dspt", "dsvhtg", "dtdđ", "dtg", "dttblđ", "dvdlđl", "dđ", "gcmnd", "gcnqsdđ", "gdlđtvl", "gdvl",
                 "gpmn", "gpsg", "gtgt", "gtln", "gtn", "gtt", "gtđb", "gđt", "gđđt", "hcb", "hcm", "hcnn", "hcqt",
                 "hcsn", "hđsc", "hhtcvn", "hhđ", "hlatlđca", "hlvqg", "hnbvn", "hnhl", "hpq", "hpt", "hqhp", "hscc",
                 "hsđk", "htth", "hvbc", "hvđ", "hvnh", "hxk", "hđcd", "hđdn", "hđkt", "hđmbtb", "hđth", "hđđg",
                 "hđđtlcnđt", "kdtt", "kgbc", "khhs", "khktbhlđ", "khktvn", "khlsvn", "khtdtt", "khtt", "khvn",
                 "khxhvn", "klhttqg", "knds", "ksgm", "kshs", "ktnn", "ktsg", "ktđc", "ktđn", "kvpn", "lhc", "lkck",
                 "lsv", "ltbtt", "ltths", "ltv", "lvc", "lxl", "lđbcvn", "lđbt", "lđcn", "lđg", "lđn", "lđqp", "lđst",
                 "lđtt", "lđvn", "lđđkvn", "mgmn", "msmv", "mtdtgpmnvn", "mttp", "mttq", "mvs", "nbvn", "nchs", "ncm",
                 "ndgđ", "ndtc", "ndtq", "ngnd", "nhcsxhvn", "nhd", "nhg", "nhhh", "nhnt", "nhvn", "nhđt", "nkbv",
                 "nkx", "nkđt", "nlcx", "nlđ", "nmd", "nmitqg", "nnb", "nnnt", "nnpl", "nnpt", "nnvn", "nqd", "nsdld",
                 "nslđ", "nstp", "ntbd", "ntmk", "ntv", "ntvn", "nvh", "nvk", "nvkvn", "nvph", "nvqs", "nđtnn", "otv",
                 "pccn", "pcthcs", "pctvca", "pkkq", "pkl", "pmh", "pmv", "pmvn", "pnvn", "prcr", "ptcđ", "pthh",
                 "ptkt", "ptm", "ptntvn", "ptpm", "pđl", "pđtbs", "qbv", "qcatm", "qghn", "qhtb", "qhđt", "qlbc",
                 "qlcn", "qlgd", "qlns", "qlsd", "qlxnc", "qsdd", "qtdn", "qtg", "qthn", "qttt", "qttv", "qtvn", "qtvp",
                 "qđnd", "qđnh", "qđxb", "rlc", "scn", "sctm", "scđb", "sdlđ", "sdt", "sgk", "shbd", "skbmte", "sklđ",
                 "sktd", "slv", "slđtbxh", "smmt", "smđ", "sscđ", "stbth", "stdm", "sttn", "svđh", "tbcn", "tbd",
                 "tbktd", "tbktđ", "tbn", "tbnn", "tbtg", "tbđt", "tcc", "tccn", "tcdn", "tckd", "tckt", "tclđ", "tcn",
                 "tdt", "tevn", "tgn", "thcs", "thcsnđ", "thqct", "thtt", "thvn", "thyt", "thđ", "tkbđ", "tkslhckqt",
                 "tktq", "tkts", "tll", "tlva", "tlđ", "tmb", "tmcpqđ", "tmh", "tngt", "tnph", "tnpt", "tntp", "tpcl",
                 "tpcm", "tpcp", "tpdl", "tphcm", "tpqn", "tpsa", "tpvt", "tpđn", "tsbđ", "tscd", "tshl", "tstc",
                 "ttatgt", "ttcc", "ttchg", "ttcn", "ttgd", "ttgdct", "tthctl", "tthn", "tths", "tthtcc", "tthtkh",
                 "ttksgt", "ttlđ", "ttncqh", "ttnnđ", "ttqlkt", "ttthdl", "tttttd", "ttudcnm", "ttvh", "ttvhp", "ttxh",
                 "ttytq", "ttđa", "ttđn", "tvvn", "tđbk", "tđcncsvn", "tđydbl", "ubatgtqg", "ubdsgđ", "ubkttu", "ubnn",
                 "ubqgtkcn", "ubđt", "vhtn", "vksndtp", "vltk", "vnah", "vnd", "vnnkt", "vscc", "vslđ", "vstp", "vtci",
                 "vthksg", "vtth", "vtthpy", "vttm", "vttn", "vtvt", "vtxd", "vđv", "xdcb", "xdgv", "xdhn", "xdnn",
                 "xktv", "xlctr", "xmtc", "xnkni", "xnkt", "xvnt", "ydtn", "yhcthd", "đbcl", "đcn", "đcsvn", "đhcn",
                 "đhcnvc", "đhct", "đhcđ", "đhd", "đhgtvt", "đhhp", "đhhđ", "đhkhxh", "đhl", "đhn", "đhp", "đhqb",
                 "đhqn", "đhsphn", "đhspkt", "đhtb", "đhtm", "đhđcqt", "đhđlhq", "đhđn", "đkph", "đmn", "đmp", "đnk",
                 "đnđ", "đt", "đtbđvn", "đtdđ", "đthvn", "đtla", "đtnvn", "đtst", "đtxdcb", "đuk", "đvdt", "xhcn",
                 "khđt", "qh", "kts", "cbccvc", "bchcđ", "lhpnvn", "dsgđte", "tnmtnđ", "lđxh", "pclbtư", "ahllvt",
                 "gđbv", "attp", "ttvhtư", "bxh", "cbcnlđ", "cbnv", "sphn", "ktcn", "dthvn", "ttdbkttvtư", "nntư",
                 "kttvtư", "kđtmtt", "gdmn", "lđxk", "nvkd", "bhl", "bhlđ", "bhr", "blđ", "bmx", "bqldatl", "bqldatđ",
                 "bvlđ", "bvtvsg", "bvđhyd", "bđathh", "bđd", "cbq", "cccp", "cctt", "chdcnd", "clbbđ", "cnnhcsxh",
                 "cnsh", "cntb", "cptmmn", "cptp", "cpxl", "cqđt", "cste", "csvc", "csđttpqlkt", "cth", "cthđqt",
                 "ctkh", "cvbt", "cvd", "cvl", "cxl", "cđ", "cđckcn", "cđct", "cđdl", "cđgd", "cđspkt", "cđđs", "dcđn",
                 "ddns", "dhg", "dndlđtcnbk", "dvtmth", "dđt", "gddh", "gdlđ", "gmtđ", "gntt", "gpnk", "gtnn", "gtvltn",
                 "gđpytt", "hbx", "hcđ", "hktt", "htxh", "htxp", "hđbc", "hđbtht", "hđgghb", "hđgs", "hđql", "hđtđ",
                 "kcnhp", "kdth", "kkc", "kqlđb", "ksv", "ksxx", "ksxxpt", "ktqp", "kđclgd", "kđtm", "lmđ", "lđnt",
                 "lđtndctg", "mlct", "mmt", "msvt", "mtđh", "mxd", "mđ", "mđt", "nccl", "nckhkt", "ncđ", "nhđ", "nhđa",
                 "nlvn", "nmnđ", "nmđqn", "nnba", "nttc", "nvqg", "pgs", "pmd", "ptks", "ptnn", "ptvmđt", "ptđt", "qhb",
                 "qhcc", "qhvn", "qhđ", "qk", "qlcl", "qldt", "qlvh", "qlđđ", "qn", "qnh", "qtm", "qtn", "qttc", "qđt",
                 "sbh", "sctbcn", "sln", "srkstct", "svhtt", "sxbb", "sđ", "sđh", "sđt", "tandtc", "tbcs", "tcbd",
                 "tcvg", "tcxd", "tdtc", "tgs", "thcn", "thlv", "thđh", "tkcn", "tkd", "tks", "tksvn", "tlcs", "tntq",
                 "tnđh", "tnđt", "tpnt", "tqb", "tsbht", "tskh", "tsđ", "tsđkdt", "ttcb", "ttgđ", "ttgdck", "ttgtcc",
                 "tthlttqg", "ttlkck", "ttms", "tttg", "ttth", "tttkcn", "tttt", "ttty", "ttvn", "ttyt", "ttđ", "tvkt",
                 "txbl", "ubbv", "ubmttqvn", "ubplqh", "ubtc", "ubvnvnonn", "vbvbm", "vdcn", "vdv", "vhcs", "vhpd",
                 "vlcm", "vlxd", "vmn", "vncntts", "vnqdđ", "vpbvntd", "vsmtnt", "xdct", "xdđ", "xhd", "xnld", "xnltnt",
                 "xnxd", "đavn", "đbgtđt", "đct", "đcđ", "đdb", "đg", "đhnh", "đhqg", "đht", "đhđ", "đhđcđ", "đkhktt",
                 "đktt", "đlbđ", "đq", "đtlt", "đtn", "đtqv", "pgs", "hcđ", "klgd", "slna", "ubndtp", "gđtla", "sbd",
                 "khhgđ", "bkl", "nsut", "tntc", "bch", "bckt", "bcđtp", "bcđts", "bdcm", "bdd", "bđl", "bhtn", "bhtt",
                 "bhyttd", "blđmnv", "bnsr", "bqlc", "bqldl", "bqlrphđn", "bqt", "bqth", "brdđ", "btbnn", "btcn",
                 "btgpmb", "bttp", "btv", "btvc", "bvcctv", "bvcr", "bvmp", "bvntd", "bvntdvn", "bvtvag", "bvđkhy",
                 "bxcl", "bxđt", "bđctm", "bđhda", "cakh", "capđv", "catpđn", "cbxh", "cctcđlcl", "cctp", "cdgsnn",
                 "cgqsdđ", "cktt", "clx", "cmđsdđ", "cnqshđ", "cpbvtv", "cpckxd", "cpcmvntd", "cpdmnt", "cpdvbv",
                 "cpdvdlđl", "cpitn", "cpkspt", "cpqt", "cptn", "cqld", "cshsđn", "cskd", "csthn", "cstp", "csvl",
                 "csđ", "csđn", "csđttpttxh", "ctbt", "ctclqg", "ctgd", "ctgtcc", "cvcs", "cvvh", "cđat", "cđkcn",
                 "cđktcn", "cđspđl", "datc", "daxdnmns", "dcđ", "đhnt", "đhxd", "đkv", "dldkpđ", "dmah", "đmđ", "dmvn",
                 "dnsg", "dskhhgđ", "đtđ", "đtptnhn", "dvkdth", "dvlđ", "dvnh", "dvptđt", "gbt", "gcn", "gcnsk", "gđxh",
                 "glmb", "gptm", "kdbh", "kdlsttt", "kgxcc", "khcnxd", "khkthn", "khkths", "kkts", "kkttn", "klcđ",
                 "knht", "knncnc", "kqlgt", "ksgt", "kstđ", "ktgsln", "ktnht", "ktstq", "kttcđlcl", "ktthhn", "ktvhvn",
                 "ktxb", "ktđđx", "kđtmnsct", "lchh", "lcnpma", "ubkn", "ubkttuhg", "ubnvn", "ubpc", "ubqgvstbcpn",
                 "ubtcns", "ubvcvđxh", "ubđkcg", "upđttl", "utqlv", "utđtt", "vblh", "vbvskte", "vddqg", "vgsv", "vhl",
                 "vhlkh", "vkhtt", "vkttđ", "vkttđpn", "vmnm", "vnca", "vnnb", "vphu", "vpktst", "vpđkqsdđ", "vqgtc",
                 "vspd", "vsytcc", "vta", "vtđ", "vttph", "vtđs", "vtđshn", "vvsytcc", "vđhmnđ", "vđt", "xdqđ",
                 "xkvsđt", "xtđt", "yhlđ", "ytcc", "đbgt", "đbđt", "đhag", "đhcntt", "đhcq", "đhhhvn", "đhkhtnhn",
                 "đhm", "đhnnhn", "đhthhn", "đhyhn", "đkkv", "đklđ", "đku", "đkđ", "đlcl", "đlhn", "đllđ", "đmtc",
                 "đqlđs", "đsđmtq", "đtcc", "đtml", "đtrnn", "đttcp", "đvsncl", "đvut", "tand", "chxhcn", "hlv", "gs",
                 "nsưt", "sxkd", "annd", "atnđ", "bbt", "bbvt", "bcbb", "bchpclb", "bcn", "bcnđa", "bctc", "bcđpclb",
                 "bhgđ", "bhnt", "bhs", "bhv", "bhyttn", "bkhn", "bkvn", "blgđ", "bltgđ", "bmsl", "bmtk", "bqbđ",
                 "bqlkdl", "bqlrph", "bqđ", "bsgđ", "btk", "btqđ", "btth", "bttn", "bttnvn", "bvh", "bvkvth", "bvmtvn",
                 "bvnlts", "bvtmhh", "bvvp", "bvđ", "bvđkbn", "bvđkhb", "bvđktb", "bxmt", "bxmđ", "bđ", "bđkh", "bđn",
                 "bđt", "bđtn", "bđtp", "bđts", "bđvh", "cbqlgd", "cbsk", "cchc", "cchksbmt", "ccnn", "ccpđ", "ccqltt",
                 "cctc", "ccth", "cctn", "ccvc", "ccđspn", "cgc", "cgcn", "chcc", "chhmh", "clbpn", "clgd", "cmhs",
                 "cmlt", "cnqg", "cnqp", "cntn", "cntt", "cnvn", "cpht", "cpktxd", "cptbd", "cpvt", "cpxnk", "cpđt",
                 "cpđttm", "cqsdđ", "cscc", "csdl", "csg", "cssxnt", "csxh", "ctc", "ctch", "ctgđ", "ctkb", "ctmt",
                 "ctsn", "cttcmr", "cttg", "ctth", "cttl", "ctv", "ctxd", "ctđ", "ctđkh", "cvcx", "cvp", "cvvt", "cđbt",
                 "cđbvn", "cđbđbp", "cđcntp", "cđgt", "cđgtvt", "cđmt", "cđts", "cđvhnt", "dbkttv", "dbđv", "dcđ",
                 "ddqg", "ddtđc", "ddvn", "ddđhh", "dhsvn", "dkt", "dlnt", "dndd", "dngh", "dnnqd", "dnnvv", "dnt",
                 "dnvvn", "dqtv", "dstntg", "dtbb", "dttstn", "dvbv", "dvci", "dvdl", "dvtt", "dvvltn", "dvđa",
                 "gcnclct", "gcnkqts", "gcnđkkd", "gcnđt", "gd", "gdcn", "gdcđ", "gdqp", "gdđh", "ghpgvntn", "gmmtđ",
                 "gnct", "gpmb", "gpxd", "gpđt", "grttcc", "gsts", "gtttđpt", "gvch", "gđ", "gđkkd", "gđns", "gđsx",
                 "gđxh", "hagl", "hbh", "hc", "hcb", "hcch", "hctl", "hdnt", "hdtq", "hdxl", "hhbđsnđvn", "hhtg",
                 "hhtm", "hhvn", "hhvt", "hhx", "hhđh", "hkdd", "hkgr", "hlatlđ", "hmnđ", "hmtn", "hmtt", "hn", "hndn",
                 "hqđt", "hsdt", "hsxc", "hsđkdt", "htmt", "htpl", "htpt", "htqt", "httl", "hvlq", "hvnclc", "hvqhqt",
                 "hvtc", "hvttn", "hđbđg", "hđc", "hđcdgsn", "hđds", "hđdvpl", "hđgk", "hđgt", "hđhtt", "hđnn",
                 "hđntnn", "hđqggd", "hđqpan", "hđt", "hđtt", "hđttcc", "hđttqg", "hđtv", "hđxx", "hđđt", "kbnn",
                 "kbtb", "kbttn", "kcbmp", "kchtđs", "kcnc", "kdbđs", "kddv", "kdlsl", "kdlvt", "kh", "khh", "khth",
                 "khtl", "khvl", "kktnt", "kktvp", "klhp", "kntc", "knxk", "kpn", "kqlgtđt", "kskh", "kskđk", "ksndtc",
                 "ksxd", "ktcs", "ktht", "ktm", "ktmn", "ktqs", "ktqt", "ktst", "kttmđb", "kttn", "kttvnb", "kttđ",
                 "ktv", "ktvn", "ktđđ", "kvcgt", "kvhgđ", "kvts", "kđcl", "kđtvv", "lhcđ", "lhq", "lhsvn", "lhthtq",
                 "lhtn", "lmđn", "lsvh", "lsx", "ltlt", "lvsđn", "lđbđqg", "lđct", "lđh", "lđkbđs", "lđnn", "lđtc",
                 "lđtd", "lđđ", "lđđt", "macđ", "mbqh", "mgck", "mghn", "mhql", "mnbc", "mncv", "mndbt", "mpqt", "mslđ",
                 "mtth", "mtxt", "mtđb", "mtđt", "mxnb", "mđln", "nbh", "nccb", "nckh", "ndtts", "nhcsxh", "nhct",
                 "nhctvn", "nhpt", "nhptvn", "nhtmcp", "nkkn", "nlcxh", "nld", "nlsh", "nltqd", "nlts", "nltt",
                 "nlđctn", "nmcbts", "nmct", "nmnth", "nmtl", "nmtđ", "nmxlnttt", "nmxm", "nmđcr", "nmđnt", "nncđdc",
                 "nptt", "nqh", "nqlg", "nqtm", "nsnn", "nsttn", "nsvhcn", "nsx", "ntk", "ntts", "nvbđd", "nvgc",
                 "nvhcc", "nvs", "nvtv", "nvtvbs", "nđk", "nđm", "nđt", "nđvn", "nđđ", "onkq", "pcdcgc", "pcmt",
                 "pcthtl", "pctn", "pctnxh", "pcv", "pgcm", "pgdvl", "pgtp", "pkkv", "pktn", "pkđk", "plctrtn",
                 "plttnc", "pmdc", "pmnm", "pmnđ", "pnmd", "pspt", "ptdtnt", "ptgmhs", "pthtckcn", "ptnb", "ptnt",
                 "ptntđ", "ptt", "ptth", "pttn", "pttt", "ptvn", "ptxd", "pv", "pvshđl", "pvts", "pvtt", "qcctnb",
                 "qchq", "qhct", "qhkt", "qhlđ", "qkhlm", "qktđ", "qlbvr", "qlbx", "qlc", "qlclctgt", "qlct", "qldatl",
                 "qldvn", "qlmt", "qlnn", "qlts", "qp", "qppl", "qrtd", "qsd", "qshcttđ", "qshnđ", "qshtt", "qtkd",
                 "qtnl", "rntt", "sdđ", "sgdvl", "sggp", "sgnt", "sgtt", "shcn", "shnn", "shtt", "skkn", "skst", "sktt",
                 "sp", "spst", "stktn", "stmt", "sv", "svbc", "svd", "svnn", "svtn", "svvn", "sxh", "sxsh", "sxxnk",
                 "sđd", "sđk", "tađp", "tbdh", "tbdđtt", "tbkt", "tbktsg", "tbmmn", "tbt", "tbth", "tbtkđ", "tbđ",
                 "tcbp", "tccs", "tcdl", "tcdlvn", "tchtq", "tcm", "tcmrqg", "tctc", "tctd", "tctk", "tctt", "tcvsg",
                 "tcxdvn", "tcđlcl", "tcđtct", "tddc", "tdm", "tdnt", "tdtkc", "tgdđ", "tggt", "tgpn", "tgvh", "thdl",
                 "thgt", "thkt", "thns", "thnxc", "thqg", "thv", "thvp", "tkbs", "tkclp", "tkhq", "tkkt", "tktst",
                 "tktt", "tlgt", "tlgtks", "tltn", "tlvlđ", "tlvđ", "tlđlđvn", "tmtdts", "tmthmn", "tmđt", "tncn",
                 "tnkq", "tnln", "tnsv", "tnts", "tntt", "tnv", "tnxktn", "tnxp", "tpcgc", "tpcn", "tqkc", "trphsb",
                 "tsbt", "tscđ", "tsmt", "tsnl", "tstđkqt", "ttbc", "ttbyt", "ttck", "ttcnmt", "ttcp", "ttcpqg", "ttct",
                 "ttcv", "ttcđ", "ttdb", "ttdbkttv", "ttdd", "ttdn", "ttdvđc", "ttdđ", "ttgdbđs", "ttgdckhn",
                 "ttgdlđxh", "ttgdtx", "ttgt", "ttgtsp", "ttgtvlbđ", "ttgđ", "tthc", "tthk", "tthtsv", "ttkdytqt",
                 "ttkn", "ttknhn", "ttkđqg", "ttlk", "ttll", "ttltqg", "ttlđnn", "ttnd", "ttnn", "ttnnt", "ttnt",
                 "tttc", "tttn", "ttttc", "ttttn", "tttvcđ", "tttvptvhbđ", "ttvaq", "ttx", "ttxd", "ttxttm", "ttxvn",
                 "ttytdp", "ttytdphn", "ttytnt", "ttg", "tt&tt", "ttđb", "ttđh", "ttđk", "ttđt", "ttđđhtđ", "ttđđđqg",
                 "tvct", "tvgs", "tvhn", "tvqh", "tvvcs", "tvxd", "tvđu", "tvđđ", "txta", "txtdm", "tđ", "tđc", "tđdm",
                 "tđdmvn", "tđg", "tđkt", "tđsl", "tđtn", "ubbc", "ubcknn", "ubdt", "ubdt", "ubdtmn", "ubkhcn",
                 "ubkttư", "ubnvnonn", "ubnvonn", "ubqp", "ubtp", "ubđn", "ubđnqh", "ubđp", "utbmtbg", "utctc", "utdv",
                 "uttlt", "uvbct", "vbcc", "vcdd", "vcp", "vdtp", "vhcđ", "vhgdtntn", "vhls", "vhnlđ", "vhntcdtts",
                 "vkhktnnmn", "vkttđmt", "vlkt", "vltl", "vlđc", "vn", "vnclc", "vnqđ", "vpbq", "vpcc", "vps", "vptt",
                 "vqg", "vsattp", "vsmt", "vstbpn", "vsv", "vtbsg", "vtcc", "vtdđ", "vthk", "vthkđssg", "vtqt", "vttlm",
                 "vttđ", "vđqg", "xclc", "xdkp", "xdll", "xdmt", "xdvl", "xgct", "xhc", "xhds", "xhh", "xhhctth",
                 "xhhgd", "xhtdte", "xklđ", "xlhn", "xlnt", "xncbtp", "xnck", "xnkdns", "xnkdnsđđ", "xnkts", "xnm",
                 "xnqd", "xtg", "xtn", "xtnđ", "xttm", "xđxm", "xđđ", "ydbl", "yhct", "yhlscbnđ", "ytdp", "đaqđ",
                 "đbbb", "đbct", "đbgpmb", "đbkk", "đbtsxb", "đbđth", "đcxb", "đdnvk", "đdtc", "đdv", "đhb", "đhbk",
                 "đhbkhn", "đhc", "đhclc", "đhhn", "đhkt", "đhnn", "đhnt", "đhqghn", "đhqgvn", "đhskđa", "đhtn", "đhtt",
                 "đhvhhn", "đhđd", "đkdt", "đkk", "đkkh", "đkla", "đktc", "đkxm", "đkđt", "đlh", "đlnl", "đltl", "đlđn",
                 "đmgd", "đn", "đntltb", "đsct", "đtbt", "đtcbl", "đtck", "đtha", "đtht", "đtlb", "đtnt", "đttc", "đtv",
                 "đtxd", "đtxdhn", "đvbc", "đvhd", "đvtl", "đx", "đxt", "đđn", "tx", "đbscl", "đh", "dntn", "nnptnt",
                 "tnhh", "bgh", "tncs", "hs", "hcv", "đkvđ", "bv", "nh", "dv", "xh", "gv", "ql", "lđpt", "lđ", "dn",
                 "csđt", "lđtbxh", "khxhnv", "gsts", "gdđt", "nnptnt", "hssv", "atvsv", "bđbp", "bvkv", "đd", "pgđ",
                 "đhnn", "dlvn", "tnxh", "bqpm", "kdns", "tncđ", "hpgp", "hđkh", "bđs", "cssx", "gtnt", "ctnh",
                 "đktưct", "tbktvn", "qlsdtsnn", "bbđ", "bcs", "blđtb", "btbg", "btx", "bvqs", "bvt", "byt", "bđbl",
                 "cbnls", "ccc", "ccty", "cdl", "clc", "clk", "cngc", "cntd", "cpn", "cptvxdvcn", "csx", "cva", "cđđb",
                 "daxd", "đbp", "đgh", "đhl", "đhy", "dls", "kpxdn", "dntvn", "dqb", "dscc", "dstl", "đvn", "gcnqsđ",
                 "ghsqgmt", "gmn", "gsg", "gtmt", "gđca", "hccb", "hcmhs", "hcoct", "hcsp", "hctd", "hdh", "hdvc",
                 "hhbđs", "hhgđ", "hhk", "hhkvgnvn", "hhqcvn", "hhqt", "hhtc", "hhtmtu", "hhtđ", "hlhtnvn", "hlvc",
                 "hmrbl", "hnm", "hnqg", "hnydtn", "hpc", "hpnt", "hqla", "hqtct", "hskt", "hsmt", "hsn", "hsđn",
                 "htcc", "htg", "htmhqgvn", "htvh", "htxdvnn", "htđđ", "hvcnttđl", "hvhcqg", "hvkhqs", "hđbhnt",
                 "hđcdgscs", "hđcm", "hđhgcs", "hđkc", "hđktqh", "hđlb", "hđmc", "hđsk", "hđtp", "hđtđkt", "hđvb",
                 "hđxltnvc", "hđđb", "hđđtđ", "kcbt", "kchtlh", "kcq", "khpt", "kqxs", "krl", "ktgđ", "ktnđ", "ktvp",
                 "ktxd", "lhkhkt", "lhđsvn", "lkdbh", "lllđ", "llvh", "lmdc", "lmlm", "lnb", "lqv", "lsq", "lstdđt",
                 "ltqg", "ltqđtd", "lvh", "lvđ", "lđtndc", "mbdb", "mbhtđ", "mcp", "mdct", "mdm", "mg", "mhav",
                 "mhtntn", "mkd", "mlc", "mlss", "mpd", "mst", "mtdtgp", "mtdttn", "mtgpmn", "mtld", "mtđ", "mtđđ",
                 "mvd", "nbct", "nbk", "nccvcm", "ncd", "ncgcd", "nckt", "ncltg", "nctncn", "ncunlcc", "ncđđ", "ngtt",
                 "nhcptm", "nhda", "nhtg", "nhttđ", "nhxn", "nkhhct", "nmc", "nmcbmcs", "nmld", "nmlddq", "nmn",
                 "nmplhr", "nmth", "nmxlr", "nnc", "nnct", "nnktc", "nnđp", "nnđtvv", "nocv", "noxh", "npp", "npv",
                 "nql", "nsnd", "nsvmđt", "nsvsmt", "ntbv", "ntlstp", "ntn", "ntnn", "ntnn", "ntvt", "nvca", "nvhc",
                 "nvl", "nxbctqg", "nxbt", "nxbtn", "nyg", "nđd", "nđl", "nđtb", "pbgdpl", "pbk", "pbtl", "pbttu",
                 "pbvh", "pc", "pcbd", "pcccr", "pcgdbth", "pclbmn", "pctpcnc", "pcvt", "pdv", "pkb", "pldskt", "plrtn",
                 "pmtd", "pncl", "pnkb", "pntp", "pq", "psdn", "ptktxd", "ptll", "ptnbt", "ptthdl", "ptthtt", "pttnđ",
                 "pvkt", "pxa", "pxn", "pđp", "qbđ", "qcdc", "qcpkkq", "qdđ", "qggd", "qhtptnlcntt", "qhxd", "qkd",
                 "qlgtđt", "qlhcttxh", "qlktcttl", "qllct", "qllđvnn", "qlnlts", "qlp", "qlrph", "qlt", "qltl",
                 "qlttbđs", "qlvsattp", "qlđhvthkcc", "qpn", "qtb", "qtdnd", "qtkdqt", "qđgđt", "rhm", "rlaacc", "rlcd",
                 "rlla", "rlmm", "rlpl", "rnlg", "rtcn", "rvp", "rđd", "sbcr", "scd", "sdd", "sddbt", "sdh", "sdđnn",
                 "shh", "shpt", "skcđ", "skss", "skđ", "smh", "smn", "srkst", "stqc", "sttk", "svnckh", "svt", "svđtt",
                 "sxkd", "sxxnkbd", "tadn", "tb", "tccq", "tcct", "tcg", "tckh", "tcmn", "tcmr", "tcnh", "tcqg", "tcqt",
                 "tcss", "tctcdlcl", "tcytqb", "tcđ", "tcđc", "tdtt", "telt", "tgct", "tghm", "tglx", "tgm", "tgns",
                 "tgvt", "thads", "thapt", "thbđ", "thcb", "thcvn", "thktnv", "thnc", "thytla", "tkb", "tkmx",
                 "tksbpck", "tkđ", "tld", "tlgd", "tlh", "tlnl", "tlns", "tmdk", "tmm", "tmnđ", "tmss", "tmtv", "tmxnk",
                 "tndctg", "tnds", "tnks", "tnndtp", "tnstn", "tnvsmt", "tp", "tpb", "tpbb", "tpg", "tpkat", "tpmn",
                 "tppy", "tqc", "tqdn", "tqs", "ts", "ts", "tsdđ", "tsdđnn", "tspt", "tstd", "tsth", "tstnkdt", "tt",
                 "ttbdvh", "ttbtdtcđ", "ttbtxh", "ttbđgts", "ttdvbđg", "ttdvkh", "ttdvktqlb", "ttdvvl", "ttgdcntt",
                 "ttgdlđtvl", "ttgtđs", "tthcm", "tthlttqgi", "tthđttn", "tthđttnpy", "ttkdtm", "ttkh", "ttkhtn",
                 "ttkđtbvtvpn", "ttlhvhdl", "ttln", "ttncgc", "ttnđ", "ttpcbxh", "ttpl", "ttqbs", "ttqgqt", "ttrhm",
                 "ttsg", "ttsh", "tttmh", "tttmph", "ttton", "ttttcp", "tttttl", "ttudkh", "ttvg", "ttvhtmsg", "ttđg",
                 "ttđhbc", "tvgđ", "tvn", "tvth", "tvtltt", "txct", "tyts", "tđbl", "tđv", "ub", "ubattp", "ubattplmca",
                 "ubbvcste", "ubctn", "ubhckc", "vcty", "vlca", "vpcn", "vpktst", "vsđc", "vttc", "vxl", "xdcn",
                 "xdcsct", "xdktmn", "xdnln", "xdđtnđ", "xlntcntt", "xmđ", "xntl", "xxst", "ytlđ", "ytvn", "đakt",
                 "đbhsxb", "đbp", "đbđvn", "đdt", "đhdlkt", "đhkn", "đhqs", "đhvl", "đlbtđ", "đltpkđ", "đt", "đtdtbv",
                 "đtnm", "đtth", "bs", "ch", "pgsts", "undp", "vnđ", "vnd", "đồng/kg", "kw", "usd/ounce", "usd/đồng",
                 "kh&cn", "nq/tw", "sn", "iot", "lđtb&xh", "tcn"}



re_number_scale_list = [
    "-*\d{1,7}[ ]*",
    "-*\d{1,7}[\.,]\d{1,7}[ ]*",
    "\d{1,7}[\.,\-x]\d{1,7}[ ]*",
    "\d{1,3}[\.,]\d{3}[\.,]\d{1,5}[ ]*",
    "\d{1,3}[\.,]\d{3}[\.,]\d{1,3}[\.,]\d{1,5}[ ]",
]
re_number_scale_list = [
    item + "(triệu|tỷ|nghìn|s|h|p|gram|g|kg|mg|hz|cm|mm|m|km|mb|gb|tb|l|m3|m2|ha|km2|km3|kw|w|kWh|kwh|v|%|usd|vnd|đ|euro|cent|kb|%|\$|euro|s|m|nm|g|ampe|mol|cd|n|pa|atm|đ|ha|h|kb|s|ml|l|gb|mb|kb|kg|mg|m3|km3|dm3|cc|cm3|m2|km2|dm2|cm2|mm2|km|dm|cm|mm|nm|mph|ft|kn|nm|gn|mn|kn|mn|j|kj|mj|gj|mw|kw|w|wh|mwh|kwh|mev|ev|cal|kcal|oc|of|ok|dp|wb|diop|bq|db|min|sec|mmhg|ma|rad|hz|lb|oz|gal|inch|vnđ|vnd|rm|rub|vg|ph|s2)"
    for item in re_number_scale_list]
